@@ -1,12 +1,12 @@
 <?php
 #-------------------------------------------------------------------------------
 #
-# Module : AdvancedContent (c) 2010-2011 by Georg Busch (georg.busch@gmx.net)
+# Module : AdvancedContent (c) 2010-2013 by Georg Busch (georg.busch@gmx.net)
 #          a content management tool for CMS Made Simple
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
-#          CMS Made Simple is (c) 2004-2011 by Ted Kulp
+#          CMS Made Simple is (c) 2004-2013 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.9.2
+# Version: 0.9.4
 # File   : action.defaultadmin.php
 # Purpose: performs the default backend action if "Extensions->AdvancedContent"
 #          is selected
@@ -24,19 +24,16 @@ if(!$this->CheckPermission('Manage AdvancedContent Preferences')
 }
 $active_tab = 'prefs';
 if(isset($params['active_tab']))
-{
 	$active_tab = $params['active_tab'];
-}
+
 $errormessage = '';
 if(isset($params['errormessage']))
-{
 	$errormessage .= $params['errormessage'].'<br />';
-}
+
 $message = '';
 if(isset($params['message']))
-{
 	$message .= $params['message'].'<br />';
-}
+
 $tabs = array();
 
 if($this->CheckPermission('Manage AdvancedContent Preferences'))
@@ -45,100 +42,48 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 		$this->lang('prefs'),
 		($active_tab=='prefs'?true:''));
 	
-	if($this->GetPreference('switch_redirect_params',false))
-	{
-		$this->smarty->assign('switch_redirect_params_text',$this->lang('switch_redirect_params'));
-		$this->smarty->assign('switch_params1_input',
-		$this->CreateLink($id, 'switchParams', $returnid,
-			cmsms()->get_variable('admintheme')->DisplayImage('icons/system/import.gif', '','','','systemicon') .
-			'&nbsp;' . $this->lang('switch_params', $this->lang('redirectparams'),$this->lang('feu_params')),
-			array('old_type'=>'redirect_params','new_type'=>'feu_params'),
-			'',
-			false,
-			false,
-			'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
-				$this->lang('confirm_switchparams', $this->lang('redirectparams'),$this->lang('feu_params')) .
-				'\')) {AdvancedContent.switchParams(this.href);} return false;"'));
-		
-		$this->smarty->assign('switch_params2_input',
-		$this->CreateLink($id, 'switchParams', $returnid,
-			cmsms()->get_variable('admintheme')->DisplayImage('icons/system/import.gif', '','','','systemicon') .
-			'&nbsp;' . $this->lang('switch_params', $this->lang('redirectparams'),$this->lang('custom_params')),
-			array('old_type'=>'redirect_params','new_type'=>'custom_params'),
-			'',
-			false,
-			false,
-			'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
-				$this->lang('confirm_switchparams', $this->lang('redirectparams'),$this->lang('custom_params')) .
-				'\')) {AdvancedContent.switchParams(this.href);} return false;"'));
-	}
-	#else
-	#{
-	#	$this->smarty->assign('switch_params1_input',
-	#	$this->CreateLink($id, 'switchParams', $returnid,
-	#		cmsms()->get_variable('admintheme')->DisplayImage('icons/system/import.gif', '','','','systemicon') .
-	#		'&nbsp;' . $this->lang('switch_params', $this->lang('custom_params'),$this->lang('feu_params')),
-	#		array('old_type'=>'custom_params','new_type'=>'feu_params'),
-	#		'',
-	#		false,
-	#		false,
-	#		'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
-	#			$this->lang('confirm_switchparams',$this->lang('custom_params'),$this->lang('feu_params')) .
-	#			'\')) {AdvancedContent.switchParams(this.href);} return false;"'));
-	#	
-	#	$this->smarty->assign('switch_params2_input',
-	#	$this->CreateLink($id, 'switchParams', $returnid,
-	#		cmsms()->get_variable('admintheme')->DisplayImage('icons/system/import.gif', '','','','systemicon') .
-	#		'&nbsp;' . $this->lang('switch_params', $this->lang('feu_params'),$this->lang('custom_params')),
-	#		array('old_type'=>'feu_params','new_type'=>'custom_params'),
-	#		'',
-	#		false,
-	#		false,
-	#		'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
-	#			$this->lang('confirm_switchparams',$this->lang('feu_params'),$this->lang('custom_params')) .
-	#			'\')) {AdvancedContent.switchParams(this.href);} return false;"'));
-	#	
-	#}
-	
-	
 	$this->smarty->assign('startform', $this->CreateFormStart($id,
 		'savePrefs', $returnid,'post','multipart/form-data'));
 	$this->smarty->assign('endform', $this->CreateFormEnd());
 	
-	$this->smarty->assign('importcontent_input',
-		$this->CreateLink($id, 'importpages', $returnid,
-			cmsms()->variables['admintheme']->DisplayImage('icons/system/import.gif', '','','','systemicon') .
-			'&nbsp;' . $this->lang('importpages', lang('content'),$this->lang('AdvancedContent')),
-			array('old_type'=>'content','new_type'=>'content2'),
-			'',
-			false,
-			false,
-			'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
-				$this->lang('confirmimport',lang('content'),$this->lang('AdvancedContent')) .
-				'\')) {AdvancedContent.importPages(this.href);} return false;"'));
+	#$this->smarty->assign('set_content_type_input1',
+	#	$this->CreateLink($id, 'set_content_type', $returnid,
+	#		cmsms()->variables['admintheme']->DisplayImage('icons/system/import.gif', '','','','systemicon') .
+	#		'&nbsp;' . $this->lang('set_content_type', lang('content'),$this->lang('AdvancedContent')),
+	#		array('old_type'=>'content','new_type'=>'advanced_content'),
+	#		'',
+	#		false,
+	#		false,
+	#		'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
+	#			$this->lang('confirm_setcontenttype',lang('content'),$this->lang('AdvancedContent')) .
+	#			'\')) {AdvancedContent.setContentType(this.href);} return false;"'));
+	#
+	#$this->smarty->assign('set_content_type_input2',
+	#	$this->CreateLink($id, 'set_content_type', '',
+	#		cmsms()->variables['admintheme']->DisplayImage('icons/system/import.gif', '','','','systemicon') .
+	#		'&nbsp;' . $this->lang('set_content_type', $this->lang('AdvancedContent'),lang('content')),
+	#		array('old_type'=>'advanced_content','new_type'=>'content'),
+	#		'',
+	#		false,
+	#		false,
+	#		'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
+	#			$this->lang('confirm_setcontenttype',$this->lang('AdvancedContent'),lang('content')) .
+	#			'\')) {AdvancedContent.setContentType(this.href);} return false;"'));
+	#
+	#$this->smarty->assign('uninstallaction_text', $this->lang('uninstallaction'));
+	#
+	#$this->smarty->assign('uninstallaction_input',
+	#	$this->CreateInputHidden($id,'uninstall_action', 0) .
+	#	$this->CreateInputCheckbox($id, 'uninstall_action', 1,
+	#		$this->GetPreference('uninstall_action', 0)) . 
+	#	$this->lang('setcontent1'));
 	
-	$this->smarty->assign('importcontent2_input',
-		$this->CreateLink($id, 'importpages', '',
-			cmsms()->variables['admintheme']->DisplayImage('icons/system/import.gif', '','','','systemicon') .
-			'&nbsp;' . $this->lang('importpages', $this->lang('AdvancedContent'),lang('content')),
-			array('old_type'=>'content2','new_type'=>'content'),
-			'',
-			false,
-			false,
-			'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
-				$this->lang('confirmimport',$this->lang('AdvancedContent'),lang('content')) .
-				'\')) {AdvancedContent.importPages(this.href);} return false;"'));
-	
-	$this->smarty->assign('uninstallaction_text', $this->lang('uninstallaction'));
-	
-	$actions = array(lang('none')=>'',
-		$this->lang('setcontent1')=>2,
-		$this->lang('setcontent2')=>3,
-		$this->lang('deletepages')=>1);
-	
-	$this->smarty->assign('uninstallaction_input',
-		$this->CreateInputDropdown($id, 'uninstall_action', $actions, '',
-			$this->GetPreference('uninstall_action')));
+	$this->smarty->assign('hide_deprecated_text',
+		$this->lang('hide_deprecated'));
+	$this->smarty->assign('hide_deprecated_input',
+		$this->CreateInputHidden($id,'hide_deprecated',0) .
+		$this->CreateInputCheckbox($id, 'hide_deprecated', 1,
+			$this->GetPreference('hide_deprecated',0)));
 	
 	$actions = array($this->lang('per_page')=>'content',
 		$this->lang('per_template')=>'template',
@@ -153,10 +98,10 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 	
 	$this->smarty->assign('collapse_block_default_text',
 		$this->lang('collapse_default',$this->lang('content_blocks')));
-		$this->smarty->assign('collapse_block_default_input',
-			$this->CreateInputHidden($id,'collapse_block_default',0) .
-			$this->CreateInputCheckbox($id, 'collapse_block_default', 1,
-				$this->GetPreference('collapse_block_default',1)));
+	$this->smarty->assign('collapse_block_default_input',
+		$this->CreateInputHidden($id,'collapse_block_default',0) .
+		$this->CreateInputCheckbox($id, 'collapse_block_default', 1,
+			$this->GetPreference('collapse_block_default',1)));
 	
 	$this->smarty->assign('message_display_settings_text',
 		$this->lang('save_collapse_status', $this->lang('block_message')));
@@ -182,9 +127,10 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 	$this->smarty->assign('use_advanced_pageoptions_input',
 		$this->CreateInputHidden($id,'use_advanced_pageoptions',0) .
 		$this->CreateInputCheckbox($id, 'use_advanced_pageoptions', 1,
-			$this->GetPreference('use_advanced_pageoptions',0),'onchange="if(!this.checked){jQuery(\'#advanced_default_options input\').attr(\'disabled\',\'disabled\');if(jQuery(\'#advanced_default_options\').css(\'display\') != \'none\'){jQuery(\'#advanced_default_options\').slideUp();}}else{jQuery(\'#advanced_default_options input\').removeAttr(\'disabled\');if(jQuery(\'#advanced_default_options\').css(\'display\') == \'none\'){jQuery(\'#advanced_default_options\').slideDown();}}"'));
+			$this->GetPreference('use_advanced_pageoptions',0),
+			'id="ac_use_advanced_pageoptions"'));
 	
-	$this->smarty->assign('advanced_default_options_style', !$this->GetPreference('use_advanced_pageoptions',0) ? 'style="display:none"' : '');
+	$this->smarty->assign('use_advanced_pageoptions', $this->GetPreference('use_advanced_pageoptions',0));
 	# default advanced pageoptions
 	
 	$this->smarty->assign('contentsettings_text', $this->lang('contentsettings'));
@@ -227,7 +173,7 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 		$feuAccess      = array_merge($feuAccess,$feusers->GetGroupList());
 		$selectedGroups = $this->GetPreference('feu_access');
 		$delim          = strpos($selectedGroups,',') === FALSE ? ';' : ',';
-		$selectedGroups = $this->CleanArray(explode($delim,$selectedGroups));
+		$selectedGroups = ac_utils::CleanArray(explode($delim,$selectedGroups));
 		
 		$this->smarty->assign('feuaccess_input',
 			$this->CreateInputHidden($id,'feu_access','').
@@ -236,7 +182,7 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 		
 		$this->smarty->assign('redirectpage_text', $this->lang('redirectpage'));
 		$this->smarty->assign('redirectpage_input',
-			$this->CreateRedirectDropdown($id,'redirect_page',
+			ac_admin_ops::CreateRedirectDropdown($id,'redirect_page',
 				$this->GetPreference('redirect_page')));
 		
 		$this->smarty->assign('inherit_text', $this->lang('inherit_from_parent'));
@@ -311,7 +257,7 @@ if($this->CheckPermission('Manage AdvancedContent MultiInputs'))
 		($active_tab=='multi_input'?true:''));
 	
 	$multi_inputs = array();
-	foreach($this->GetMultiInputList() as $multi_input)
+	foreach(ac_admin_ops::GetMultiInputList() as $multi_input)
 	{
 		$multi_inputs[$multi_input['input_id']]['edit_link'] = $this->CreateLink($id, 'editMultiInput', $returnid,
 			cmsms()->variables['admintheme']->DisplayImage('icons/system/edit.gif', '','','','systemicon'), array('input_id'=>$multi_input['input_id']));
@@ -353,7 +299,7 @@ if($this->CheckPermission('Manage AdvancedContent MultiInput Templates'))
 		($active_tab=='multi_input_tpl'?true:''));
 	
 	$multi_input_tpls = array();
-	foreach($this->GetTemplates('multi_input') as $tpl)
+	foreach(ac_admin_ops::GetTemplates('multi_input') as $tpl)
 	{
 		$multi_input_tpls[$tpl['tpl_id']]['edit_link'] = $this->CreateLink($id, 'editMultiInputTpl', $returnid,
 			cmsms()->variables['admintheme']->DisplayImage('icons/system/edit.gif', '','','','systemicon'),
@@ -381,10 +327,7 @@ if($this->CheckPermission('Manage AdvancedContent MultiInput Templates'))
 				array('set_default'=>'multi_input','tpl_id'=>$tpl['tpl_id'],'active_tab'=>'multi_input_tpl'));
 		}
 		else
-		{
 			$multi_input_tpls[$tpl['tpl_id']]['set_default_link'] = cmsms()->variables['admintheme']->DisplayImage('icons/system/true.gif', '','','','systemicon');
-		}
-		
 	}
 	$this->smarty->assign('selectall',
 		$this->CreateInputCheckbox($id,'multi_input_tpl',true,false, 'id="'.$id.'multi_input_tpl" onclick="AdvancedContent.selectAll(this)"'));
@@ -419,15 +362,13 @@ $this->smarty->assign('locale', substr(get_preference(get_userid(),'default_cms_
 
 
 if(isset($params['message']))
-{
-	$this->smarty->assign('message', $this->lang($params['message'], (isset($params['old_type']) && isset($params['new_type']) ? $this->lang($params['old_type']) . ',' . $this->lang($params['new_type']) : '')));
-}
+	echo $this->ShowMessage($this->lang($params['message'], (isset($params['old_type']) && isset($params['new_type']) ? $this->lang($params['old_type']) . ',' . $this->lang($params['new_type']) : '')));
+	#$this->smarty->assign('message', $this->lang($params['message'], (isset($params['old_type']) && isset($params['new_type']) ? $this->lang($params['old_type']) . ',' . $this->lang($params['new_type']) : '')));
 
 if(isset($params['errormessage']))
-{
-	$this->smarty->assign('errormessage', $this->lang($params['errormessage'], (isset($params['old_type']) && isset($params['new_type']) ? $this->lang($params['old_type']) . ',' . $this->lang($params['new_type']) : '')));
-}
+	echo $this->ShowErrors($this->lang($params['errormessage'], (isset($params['old_type']) && isset($params['new_type']) ? $this->lang($params['old_type']) . ',' . $this->lang($params['new_type']) : '')));
+	#$this->smarty->assign('errormessage', $this->lang($params['errormessage'], (isset($params['old_type']) && isset($params['new_type']) ? $this->lang($params['old_type']) . ',' . $this->lang($params['new_type']) : '')));
 
-echo $this->_pp . $this->ProcessTemplate('defaultadmin.tpl');
+echo $this->_pp().$this->ProcessTemplate('defaultadmin.tpl');
 
 ?>
