@@ -1,12 +1,12 @@
 <?php
 #-------------------------------------------------------------------------------
 #
-# Module : AdvancedContent (c) 2010-2011 by Georg Busch (georg.busch@gmx.net)
+# Module : AdvancedContent (c) 2010-2013 by Georg Busch (georg.busch@gmx.net)
 #          a content management tool for CMS Made Simple
 #          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
-#          CMS Made Simple is (c) 2004-2011 by Ted Kulp (wishy@cmsmadesimple.org)
+#          CMS Made Simple is (c) 2004-2013 by Ted Kulp (wishy@cmsmadesimple.org)
 #          The projects homepage is: http://www.cmsmadesimple.org
-# Version: 0.9.2
+# Version: 0.9.4
 # File   : action.deleteMultiInput.php
 # License: GPL
 #
@@ -22,6 +22,7 @@ $items        = array();
 $_params      = array();
 $message      = '';
 $errormessage = '';
+$error        = false;
 if(isset($params['input_id']))
 {
 	$items[] = $params['input_id'];
@@ -36,19 +37,20 @@ else if(isset($params['submit_bulkaction']))
 		}
 	}
 }
-if($this->DeleteMultiInput($items))
+if(ac_admin_ops::DeleteMultiInput($items))
 {
 	$_params['message'] = 'multi_input_deleted';
 	$message .= $this->lang('multi_input_deleted') . "<br />";
 }
 else
 {
+	$error = true;
 	$_params['errormessage'] = 'error_delete_multi_input';
 	$errormessage .= $this->lang('error_delete_multi_input') . "<br />";
 }
-if(!$this->DeleteTplAssoc('multi_input',$items))
+if(!$error && !ac_admin_ops::DeleteTplAssoc('multi_input',$items))
 {
-	$_params['message'] = 'error_delete_multi_input_tpl_assocs';
+	$_params['errormessage'] = 'error_delete_multi_input_tpl_assocs';
 	$errormessage .= $this->lang('error_delete_multi_input_tpl_assocs'). "<br />";
 }
 $_params['active_tab'] = 'multi_input';
