@@ -1,12 +1,12 @@
 <?php
 #-------------------------------------------------------------------------------
 #
-# Module : AdvancedContent (c) 2010-2011 by Georg Busch (georg.busch@gmx.net)
+# Module : AdvancedContent (c) 2010-2013 by Georg Busch (georg.busch@gmx.net)
 #          a content management tool for CMS Made Simple
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
-#          CMS Made Simple is (c) 2004-2011 by Ted Kulp
+#          CMS Made Simple is (c) 2004-2013 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.9.2
+# Version: 0.9.4
 # File   : event.Core.ContentPostRender.php
 # Purpose: manages expiration of a page
 # License: GPL
@@ -20,8 +20,8 @@ if ($this->GetPreference('use_advanced_pageoptions',0))
 	$config = cmsms()->GetConfig();
 	$redirect = false;
 	$db =& $this->GetDb();
-	# get all content of type advanced that need to be set to active/inactive
-	$query = "SELECT C.content_id, C.active
+	# get all content of type advanced content that need to be set to active/inactive
+	$query = "SELECT C.content_id
 		FROM " . cms_db_prefix() . "content C
 		LEFT JOIN " . cms_db_prefix() . "content_props USE_EXP
 			ON USE_EXP.content_id = C.content_id
@@ -47,39 +47,20 @@ if ($this->GetPreference('use_advanced_pageoptions',0))
 					C.active = ?
 				)
 			)
-		";
+	";
 		
-	$dbresult = $db->Execute($query, array('content2', 'use_expire_date',
+	$dbresult = $db->Execute($query, array('advanced_content', 'use_expire_date',
 		'1', 'start_date', time(), 'end_date', time(), 0, 'end_date',
 		time(), 1));
 	
-	$contents = array();
+	$contentops = &cmsms()->GetContentOperations();
 	while($dbresult && $row = $dbresult->FetchRow())
 	{
-		if($row['active'])
-		{
-			$contents[$row['content_id']] = 0;
-		}
-		else
-		{
-			$contents[$row['content_id']] = 1;
-		}
-	}
-	if(count($contents))
-	{
-		cms_content_cache::clear();
-		#$this->smarty->clear_all_cache();
-		$this->smarty->clear_compiled_tpl();
-		foreach($contents as $contentId=>$active)
-		{
-			$query = "UPDATE ". cms_db_prefix() . "content
-				SET active = ? WHERE content_id = ?";
-			$dbresult = $db->Execute($query, array($active, $contentId));
-			if($contentId == cms_utils::get_current_pageid())
-			{
-				$redirect = $contentId;
-			}
-		}
+		$content_obj = $contentops->LoadContentFromAlias($row['content_id']);
+		$content_obj->SetActive(!$content_obj->Active());
+		$content_obj->Save();
+		if($row['content_id'] == cms_utils::get_current_pageid())
+			$redirect = $row['content_id'];
 	}
 	if($redirect)
 	{
