@@ -8,16 +8,9 @@ $lang['upgraded'] = 'Module AdvancedContent is bijgewerkt naar %s';
 $lang['postinstall'] = 'Module AdvancedContent %s is ge&iuml;nstalleerd';
 $lang['postuninstall'] = 'Module AdvancedContent %s is gede&iuml;nstalleerd';
 $lang['confirmuninstall'] = 'Weet u zeker dat u de module AdvancedContent wilt de&iuml;nstalleren?';
-$lang['warninguninstall'] = 'WAARSCHUWING! U heeft geen de&iuml;nstallatie actie gebruikt in de modulevoorkeuren! Controleer voor de zekerheid dat er geen pagina&#039;s meer staan ingesteld op het type Advanced Content voordat u deze module verwijderd! U kunt anders uw CMS installatie beschadigen! ';
-$lang['warninguninstall1'] = 'WAARSCHUWING! Dit zal alle pagina&#039;s verwijderen met het type Advanced Content! ';
-$lang['warninguninstall2'] = 'OPMERKING: Dit zal alle pagina&#039;s van het AdvancedContent-type terugplaatsen naar het standaard contenttype.';
-$lang['warninguninstall3'] = 'WAARSCHUWING! Dit zal alle pagina&#039;s van het AdvancedContent-type terugplaatsten naar het standaard contenttype, daarnaast zal het alle extra inhoudsblokken verwijderen (behalve het standaard inhoudsblok).';
 $lang['notice_duplicatecontent'] = '<em><strong>Let op:</strong> Dit blok komt meerdere keren voor in het sjabloon. Alleen het eerste blok wordt hier getoond.</em>';
 $lang['error_basicattrib'] = '<em><strong>Notice:</strong> Cannot use basic content property name &#039;%s&#039; as value of param &#039;block&#039;. <br />This block is disabled. Check your page template and chose a different value of param &#039;block&#039;.</em>';
 $lang['error_expiredate'] = 'Einddatum moet na de startdatum vallen';
-$lang['youareintext'] = 'Huidige directory';
-$lang['dimensions'] = 'Afbeelding Afmetingen';
-$lang['size'] = 'Bestandsgrootte';
 $lang['inherit_from_parent'] = 'Neem over van de ouder';
 $lang['none'] = 'geen';
 $lang['invalid'] = 'fout';
@@ -34,24 +27,17 @@ $lang['useexpiredate'] = 'Gebruik verloopdatum';
 $lang['startdate'] = 'Start Datum';
 $lang['enddate'] = 'Eind Datum';
 $lang['blockcontent'] = 'Block Inhoud';
-$lang['setpageinactive'] = 'Pagina Inactief';
-$lang['deletepage'] = 'Verwijder Pagina';
-$lang['uninstallaction'] = 'De&iuml;nstalleer bewerking';
-$lang['setcontent1'] = 'Stel alle pagina&#039;s in met het type Content';
-$lang['setcontent2'] = 'Stel alle pagina&#039;s in met het type Content en verwijder alle extra content blocks';
+$lang['hide_deprecated'] = 'Verberg uitgefaseerde content types';
 $lang['prefsupdated'] = 'Voorkeuren bijgewerkt';
 $lang['success'] = 'Ok&eacute;';
 $lang['error'] = 'Fout';
-$lang['deletepages'] = 'Verwijder alle pagina&#039;s met het type AdvancedContent';
-$lang['importpages'] = 'Stel alle pagina&#039;s in met het type %s naar het type %s.';
-$lang['confirmimport'] = 'Weet u zeker dat u het contenttype van alle pagina&#039;s wil wijzigen?';
 $lang['toggle_message'] = 'Verberg dit bericht';
 $lang['contentsettings'] = 'Standaard AdvancedContent Instellingen';
 $lang['redirectparams'] = 'URL params to append when redirecting (param1=value1 param2=value2 ...)';
 $lang['evaluatesmarty'] = 'Use smarty to create the params';
 $lang['error_loading_module'] = '<em><strong>Error:</strong> Could not load module &#039;%s&#039;. (Defined for block &#039;%s&#039; in your page template.)</em>';
 $lang['error_contentblock_support'] = '<em><strong>Error:</strong> Module &#039;%s&#039; does not support contentblocks. (Defined for block &#039;%s&#039; in your page template.)</em>';
-$lang['success_importpages'] = 'Alle pagina&#039;s van het type %s zijn succesvol gewijzigd naar %s';
+$lang['success_set_content_type'] = 'Alle pagina&#039;s van type &#039;%s&#039; succesvol gewijzigd naar &#039;%s&#039;';
 $lang['show_advancedcontent_options'] = 'Geef AdvancedContent opties tabblad weer';
 $lang['display_settings'] = '%s weergave instellingen';
 $lang['save_collapse_status'] = 'Sla de inklapstatus op van %s';
@@ -64,7 +50,7 @@ $lang['per_template'] = 'per sjabloon';
 $lang['both1'] = 'sjabloon OF pagina ';
 $lang['both2'] = 'sjabloon EN pagina';
 $lang['content'] = 'Inhoud';
-$lang['content2'] = 'Advanced Content ';
+$lang['advanced_content'] = 'Geavanceerde Inhoud';
 $lang['prefs'] = 'Instellingen';
 $lang['multi_input'] = 'Multi input';
 $lang['multi_input_tpl'] = 'Multi inputtemplates';
@@ -77,6 +63,7 @@ $lang['error_template'] = 'De template vereist dit veld en het mag niet leeggela
 $lang['error_input_fields'] = 'Invoervelden is een vereist veld en mag niet leeggelaten worden.';
 $lang['error_input_id'] = 'Geen invoer id gegeven of invoer id bestaat al.';
 $lang['error_input_id_exists'] = 'Invoer ID is al in gebruik. Kies een andere (moet uniek zijn).';
+$lang['error_pageaccess'] = 'Invalid settings for page access. The page can never be displayed. Make sure that pages that will be hidden when logged in are public what means no user groups of the FrontEndUsers module may be selected. ';
 $lang['multi_input_added'] = 'Multi Input toegevoegd.';
 $lang['multi_input_deleted'] = 'Multi Input verwijderd.';
 $lang['multi_input_updated'] = 'Multi Input bijgewerkt.';
@@ -98,7 +85,6 @@ $lang['days'] = 'dagen';
 $lang['weeks'] = 'weken';
 $lang['months'] = 'maanden';
 $lang['years'] = 'jaren';
-$lang['switch_params'] = 'Zet alle &#039;%s&#039; naar &#039;%s&#039;.';
 $lang['feu_params'] = 'Parameters voor de FrontEndUsers module';
 $lang['custom_params'] = 'Aangepaste URL-parameters om toe te voegen bij het doorverwijzen';
 $lang['confirm_switchparams'] = 'Weet u zeker dat u de inhoudseigenschap \&#039;%s\&#039; van alle pagina&#039;s wilt wijzigen in \&#039;%s\&#039;?';
@@ -115,9 +101,9 @@ Example:</p>
 <pre><code>{foreach from=$inputs item=elm}
 	{$elm.label}:&nbsp;{$elm.input}<br />
 {/foreach}</code></pre>';
-$lang['utma'] = '156861353.839426107.1319910072.1319910072.1319910072.1';
-$lang['utmz'] = '156861353.1319910072.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/viewtopic.php|utmcmd=referral';
-$lang['qca'] = 'P0-856617467-1310370352588';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1342648692.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/viewtopic.php|utmcmd=referral';
+$lang['utma'] = '156861353.1983932092.1342648692.1342648692.1342648692.1';
+$lang['qca'] = 'P0-802263609-1268423862699';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
