@@ -1,12 +1,12 @@
 <?php
 #-------------------------------------------------------------------------------
 #
-# Module : AdvancedContent (c) 2010-2011 by Georg Busch (georg.busch@gmx.net)
+# Module : AdvancedContent (c) 2010-2013 by Georg Busch (georg.busch@gmx.net)
 #          a content management tool for CMS Made Simple
 #          The projects homepage is http://dev.cmsmadesimple.org/projects/content2/
-#          CMS Made Simple is (c) 2004-2011 by Ted Kulp (wishy@cmsmadesimple.org)
+#          CMS Made Simple is (c) 2004-2013 by Ted Kulp (wishy@cmsmadesimple.org)
 #          The projects homepage is: http://www.cmsmadesimple.org
-# Version: 0.9.2
+# Version: 0.9.4
 # File   : method.upgrade.php
 # Purpose: performs a module upgrade
 # License: GPL
@@ -43,6 +43,17 @@ switch($current_version)
 			$this->RemoveEventHandler( 'Core', 'ContentPostRender');
 		}
 		$current_version = '0.9.2';
+	
+	case '0.9.3':
+		$this->SetTemplate('multi_input_SampleTemplate (since version 0.9.4)',
+'<div class="pageoverflow">
+<p>
+{foreach from=$inputs item=elm}
+	{$elm->GetProperty(\'label\')}:&nbsp;{$elm->GetInput()}&nbsp;
+{/foreach}
+</p>
+</div>');
+		$current_version = '0.9.4';
 }
 
 ?>
